import logging

from django.core.management.base import BaseCommand

from example.models import DataPooling


logger = logging.getLogger(__name__)


class Command(BaseCommand):

    def handle(self, *args, **options):
        logger.debug('>>  Checking alerts...')

        for data in DataPooling.objects.all():
            data.observer.compare(data.last_measurement)

        logger.debug('>>  All alerts checked!')



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-19 21:30
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('example', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Measurement',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.IntegerField()),
                ('timestamp', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'ordering': ('-timestamp',),
            },
        ),
        migrations.RemoveField(
            model_name='datapooling',
            name='measurement',
        ),
        migrations.AddField(
            model_name='measurement',
            name='datapooling',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='example.DataPooling'),
        ),
    ]



import logging

from django.db import models
from django.dispatch import receiver

from howl.models import Alert, Observer
from howl.signals import alert_clear, alert_notify, alert_wait


logger = logging.getLogger(__name__)


def prepare_message(obj):
    return '{0}>> {1} - {2} >>{3}<<'.format(
        obj.get_state_display().upper(),
        obj.observer,
        obj.timestamp,
        obj.value,
    )


@receiver(alert_wait, sender=Alert)
def send_warning(sender, instance, **kwargs):
    logger.debug(prepare_message(instance))


@receiver(alert_notify, sender=Alert)
def send_alert(sender, instance, **kwargs):
    logger.debug(prepare_message(instance))


@receiver(alert_clear, sender=Alert)
def send_clear(sender, instance, **kwargs):
    message = '<<<<OK>>>> {0} - {1}'.format(
        instance.observer,
        instance.timestamp,
    )
    logger.debug(message)


class DataPooling(models.Model):
    observer = models.ForeignKey(Observer)

    @property
    def last_measurement(self):
        if not self.measurement_set.first():
            return None

        return self.measurement_set.first().value

    @property
    def last_time(self):
        if not self.measurement_set.first():
            return None

        return self.measurement_set.first().timestamp


class Measurement(models.Model):
    datapooling = models.ForeignKey(DataPooling)
    value = models.IntegerField()
    timestamp = models.DateTimeField(auto_now_add=True)

    class Meta:
        ordering = ('-timestamp',)



import os


ROOT_DIR = os.path.abspath(os.path.dirname(__file__))

DEBUG = True

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(ROOT_DIR, 'database.db'),
    }
}

TIME_ZONE = 'Europe/Berlin'
LANGUAGE_CODE = 'de-DE'
SITE_ID = 1
USE_I18N = True
USE_L10N = True
USE_TZ = True
MEDIA_ROOT = ''
MEDIA_URL = ''

STATIC_ROOT = ''
STATIC_URL = '/static/'
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)

MEDIA_ROOT = os.path.join(ROOT_DIR, 'web', 'media')
MEDIA_URL = '/media/'

SECRET_KEY = 'test'

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
)

ROOT_URLCONF = 'example.urls'

# Python dotted path to the WSGI application used by Django's runserver.
WSGI_APPLICATION = 'example.wsgi.application'

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.admin',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'howl',
    'example',
)

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(ROOT_DIR, 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'debug': True,
            'context_processors': [
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.template.context_processors.debug',
                'django.template.context_processors.i18n',
                'django.template.context_processors.media',
                'django.template.context_processors.static',
                'django.template.context_processors.tz',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

LOGGING = {
    'version': 1,
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
        },
    },
    'loggers': {
        '': {
            'level': 'DEBUG',
            'handlers': ['console'],
        },
    }
}

TEST_RUNNER = ''
